@@ -6,7 +6,7 @@ $block_name = _("Monthly Events List");
  * Horde_Block_Kronolith_monthlist:: Implementation of the Horde_Block API
  * to display a list of calendar items grouped by month.
  *
- * $Horde: kronolith/lib/Block/monthlist.php,v 1.27.2.6 2006/01/03 20:50:17 chuck Exp $
+ * $Horde: kronolith/lib/Block/monthlist.php,v 1.27.2.8 2006/05/10 09:52:29 jan Exp $
  *
  * @package Horde_Block
  */
@@ -23,7 +23,10 @@ class Horde_Block_Kronolith_monthlist extends Horde_Block {
                                             'default' => '__all'),
                         'months'   => array('name' => _("Months Ahead"),
                                             'type' => 'int',
-                                            'default' => 2));
+                                            'default' => 2),
+                        'maxevents' => array('name' => _("Maximum number of events to display (0 = no limit)"),
+                                             'type' => 'int',
+                                             'default' => 0));
         $params['calendar']['values']['__all'] = _("All Visible");
         foreach (Kronolith::listCalendars() as $id => $cal) {
             $params['calendar']['values'][$id] = $cal->get('name');
@@ -79,6 +82,7 @@ class Horde_Block_Kronolith_monthlist extends Horde_Block {
                                     $endDate->mday, $endDate->month, $endDate->year);
 
         /* Loop through the days. */
+        $totalevents = 0;
         for ($i = 0; $i < $days; $i++) {
             $day = &new Kronolith_Day($startDate->month, $today + $i);
             $today_stamp = $day->getStamp();
@@ -86,6 +90,11 @@ class Horde_Block_Kronolith_monthlist extends Horde_Block {
                 continue;
             }
 
+            if (!empty($this->_params['maxevents']) &&
+                $totalevents >= $this->_params['maxevents']) {
+                break;
+            }
+
             $firstevent = true;
 
             /* Output month header. */
@@ -156,6 +165,8 @@ class Horde_Block_Kronolith_monthlist extends Horde_Block {
                     $html .= '</strong>';
                 }
                 $html .= '</td></tr>';
+
+                $totalevents++;
             }
         }
 
