@@ -33,7 +33,7 @@ define('KRONOLITH_ERROR_FB_NOT_FOUND', 1);
 /**
  * The Kronolith:: class provides functionality common to all of Kronolith.
  *
- * $Horde: kronolith/lib/Kronolith.php,v 1.263.2.49 2006/10/24 09:16:37 jan Exp $
+ * $Horde: kronolith/lib/Kronolith.php,v 1.263.2.54 2007/02/15 19:11:43 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Kronolith 0.1
@@ -227,7 +227,7 @@ class Kronolith {
      *
      * @return Kronolith_Event  The event object.
      */
-    function getRemoteEventObject($url, $eventId)
+    function &getRemoteEventObject($url, $eventId)
     {
         global $kronolith;
 
@@ -331,6 +331,7 @@ class Kronolith {
                         empty($task['completed'])) {
                         $event = &$kronolith->getEvent();
                         $event->setTitle(sprintf(_("Due: %s"), $task['name']));
+                        $event->description = $task['desc'];
                         $event->taskID = $task['task_id'];
                         $event->tasklistID = $task['tasklist_id'];
                         if ($prefs->getValue('show_task_colors') &&
@@ -355,6 +356,23 @@ class Kronolith {
             if (!is_a($events, 'PEAR_Error')) {
                 $kronolith->open(Kronolith::getDefaultCalendar(PERMS_SHOW));
                 foreach ($events as $event) {
+
+                    /* Ignore events out of our period. */
+                    if (
+                        /* Starts after the period. */
+                        $event->start->compareDateTime($endOfPeriod) > 0 ||
+                        /* End before the period and doesn't recur. */
+                        ($event->hasRecurType(KRONOLITH_RECUR_NONE) &&
+                         $event->end->compareDateTime($startOfPeriod) < 0) ||
+                        /* Recurs and ... */
+                        (!$event->hasRecurType(KRONOLITH_RECUR_NONE) &&
+                         /* ... we don't show recurring events or ... */
+                         (!$showRecurrence ||
+                          /* ... has a recurrence end before the period. */
+                          ($event->hasRecurEnd() &&
+                           $event->recurEnd->compareDateTime($startOfPeriod) < 0)))) {
+                        continue;
+                    }
                     Kronolith::_getEvents($results, $event, $startDate,
                                           $endDate, $startOfPeriod,
                                           $endOfPeriod, $showRecurrence);
@@ -820,11 +838,12 @@ class Kronolith {
      * @param integer $endstamp       The end of the time period to retrieve.
      * @param boolean $returnObj      Default false. Return a vFreebusy object
      *                                instead of text.
+     * @param string $user            Set organizer to this user.
      *
      * @return string  The free/busy text.
      */
     function generateFreeBusy($calendar, $startstamp = null, $endstamp = null,
-                              $returnObj = false)
+                              $returnObj = false, $user = null)
     {
         global $kronolith_shares, $prefs;
 
@@ -864,7 +883,7 @@ class Kronolith {
         }
 
         // Get the Identity for the owner of the share.
-        $identity = &Identity::singleton('none', $share->get('owner'));
+        $identity = &Identity::singleton('none', $user ? $user : $share->get('owner'));
         $email = $identity->getValue('from_addr');
         $cn = $identity->getValue('fullname');
 
@@ -885,7 +904,7 @@ class Kronolith {
             $params['CN'] = $cn;
         }
         if (!empty($email)) {
-            $vFb->setAttribute('ORGANIZER', 'MAILTO:' . $email, $params);
+            $vFb->setAttribute('ORGANIZER', 'mailto:' . $email, $params);
         } else {
             $vFb->setAttribute('ORGANIZER', '', $params);
         }
@@ -981,7 +1000,9 @@ class Kronolith {
                                      array('method' => 'GET',
                                            'timeout' => 5,
                                            'allowRedirects' => true));
-            @$http->sendRequest();
+            if (is_a($response = @$http->sendRequest(), 'PEAR_Error')) {
+                return PEAR::raiseError(sprintf(_("The free/busy url for %s cannot be retrieved."), $email));
+            }
             if ($http->getResponseCode() == 200 &&
                 $data = $http->getResponseBody()) {
                 $vCal = new Horde_iCalendar();
