@@ -1,4 +1,4 @@
--- $Horde: kronolith/scripts/sql/kronolith.sql,v 1.3 2004/12/21 15:52:32 chuck Exp $
+-- $Horde: kronolith/scripts/sql/kronolith.sql,v 1.3.2.1 2006/08/20 22:39:56 chuck Exp $
 
 CREATE TABLE kronolith_events (
     event_id VARCHAR(32) NOT NULL,
@@ -13,9 +13,9 @@ CREATE TABLE kronolith_events (
     event_exceptions TEXT,
     event_title VARCHAR(255),
     event_category VARCHAR(80),
-    event_recurtype VARCHAR(11) DEFAULT 0,
-    event_recurinterval VARCHAR(11),
-    event_recurdays VARCHAR(11),
+    event_recurtype INT DEFAULT 0,
+    event_recurinterval INT,
+    event_recurdays INT,
     event_recurenddate DATETIME,
     event_start DATETIME,
     event_end DATETIME,
